export default {
    "message": "Cannot use keyword 'await' outside an async function",
    "column": 18,
    "index": 17,
    "lineNumber": 1
};
